@@ -23,6 +23,7 @@
 from gnuradio.build_utils import output_glue
 
 import generate_gr_fir_filter_XXX
+import generate_gr_interp_fir_filter_XXX
 import generate_gr_freq_xlating_fir_filter_XXX
 import generate_gr_fir_sysconfig_generic
 import generate_gr_fir_sysconfig
@@ -30,12 +31,13 @@ import generate_gr_fir_util
 import generate_gr_fir_XXX
 
 def generate_all ():
+    generate_gr_fir_XXX.generate ()
     generate_gr_fir_filter_XXX.generate ()
+    generate_gr_interp_fir_filter_XXX.generate ()
     generate_gr_freq_xlating_fir_filter_XXX.generate ()
     generate_gr_fir_sysconfig_generic.generate ()
     generate_gr_fir_sysconfig.generate ()
     generate_gr_fir_util.generate ()
-    generate_gr_fir_XXX.generate ()
     output_glue ('filter')
 
 if __name__ == '__main__':
